ketl.etl package
================

Submodules
----------

ketl.etl.Pipeline module
------------------------

.. automodule:: ketl.etl.Pipeline
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ketl.etl
   :members:
   :undoc-members:
   :show-inheritance:
